@@ -66,8 +66,11 @@ class SQLAInterface(BaseInterface):
             # this decorator will add a property to the method named *_col_name*
             if hasattr(self.obj, order_column):
                 if hasattr(getattr(self.obj, order_column), '_col_name'):
-                    order_column = getattr(getattr(self.obj, order_column), '_col_name')
-            query = query.order_by("%s %s" % (order_column, order_direction))
+                    order_column = getattr(self._get_attr(order_column), '_col_name')
+            if order_direction == 'asc':
+                query = query.order_by(self._get_attr(order_column).asc())
+            else:
+                query = query.order_by(self._get_attr(order_column).desc())
         return query
 
     def query(self, filters=None, order_column='', order_direction='',
